==> sal-organization-2.25.0-20170531.073034-87-sources.jar: com/baijia/tianxiao/sal/organization/token/SyncAccountVersion.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.sal.organization.token;

import com.baijia.tianxiao.dal.org.dao.OrgSubAccountDao;
import com.baijia.tianxiao.dal.org.dao.TXCascadeAccountDao;
import com.baijia.tianxiao.dal.org.po.OrgSubAccount;
import com.baijia.tianxiao.dal.org.po.TXCascadeAccount;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.validation.ValidateTokenUtil;

import com.google.common.collect.Maps;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;

import lombok.extern.slf4j.Slf4j;

/**
 * @title SyncAccountVersion
 * @desc O(∩_∩)O~
 * @author caoliang
 * @date 2016年10月10日
 * @version 1.0
 */
@Slf4j
@Component
public class SyncAccountVersion {

    private static final int BATCH = 1000;
    private InnerSync innerSync;

    @Autowired
    private OrgSubAccountDao orgSubAccountDao;
    @Autowired
    private TXCascadeAccountDao txCascadeAccountDao;

    @PostConstruct
    public void postConstruct() {
        innerSync = new InnerSync();
        innerSync.setDaemon(true);
        innerSync.start();
    }

    @PreDestroy
    public void preDestroy() {
        innerSync.interrupt();
    }

    class InnerSync extends Thread {

        @Override
        public void run() {
            try {
                while (true) {
                    Thread.sleep(60 * 1000);
                    Map<String, Integer> accountVersionMap = Maps.newHashMap();
                    fillOrgSubAccount(accountVersionMap);
                    fillTXCascadeAccount(accountVersionMap);
                    ValidateTokenUtil.accountVersionMap = accountVersionMap;
                }
            } catch (Throwable t) {
                log.warn("InnerSync error!", t);
            }

        }

        private void fillOrgSubAccount(Map<String, Integer> accountVersionMap) {
            log.info("InnerSync start orgSubAccounts ...");
            List<OrgSubAccount> orgSubAccounts = null;
            PageDto pageDto = new PageDto();
            pageDto.setPageSize(BATCH);
            pageDto.setPageNum(1);
            int total = 0;
            do {
                orgSubAccounts = orgSubAccountDao.getAllByPageDto(pageDto);
                if (CollectionUtils.isNotEmpty(orgSubAccounts)) {
                    for (OrgSubAccount orgSubAccount : orgSubAccounts) {
                        accountVersionMap.put(ValidateTokenUtil.ORG_ID_PREFIX + orgSubAccount.getOrgId(),
                            orgSubAccount.getAccountVersion());
                    }
                }
                total += orgSubAccounts.size();
                pageDto.setPageNum(pageDto.getPageNum() + 1);
            } while (orgSubAccounts.size() == BATCH);
            log.info("InnerSync load orgSubAccounts finish! load size:{}", total);
            if(log.isDebugEnabled()){
                //log.debug("InnerSync load orgSubAccounts finish accountVersionMap :{}", accountVersionMap);
            }
        }

        private void fillTXCascadeAccount(Map<String, Integer> accountVersionMap) {
            List<TXCascadeAccount> txCascadeAccounts = null;
            log.debug("InnerSync start txCascadeAccounts ...");
            PageDto pageDto = new PageDto();
            pageDto.setPageSize(BATCH);
            pageDto.setPageNum(1);
            int total = 0;
            do {
                txCascadeAccounts = txCascadeAccountDao.getAllByPageDto(pageDto);
                if (CollectionUtils.isNotEmpty(txCascadeAccounts)) {
                    for (TXCascadeAccount txCascadeAccount : txCascadeAccounts) {
                        accountVersionMap.put(ValidateTokenUtil.CASCADE_PREFIX + txCascadeAccount.getId(),
                            txCascadeAccount.getAccountVersion());
                    }
                }
                total += txCascadeAccounts.size();
                pageDto.setPageNum(pageDto.getPageNum() + 1);
            } while (txCascadeAccounts.size() == BATCH);
            log.info("InnerSync load txCascadeAccounts finish! load size:{}", total);
        }
    }

}

==> sal-organization-2.42.0-20171030.090301-80-sources.jar: com/baijia/tianxiao/sal/organization/token/SyncAccountVersion.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.sal.organization.token;

import com.baijia.tianxiao.dal.org.dao.OrgSubAccountDao;
import com.baijia.tianxiao.dal.org.dao.TXCascadeAccountDao;
import com.baijia.tianxiao.dal.org.po.OrgSubAccount;
import com.baijia.tianxiao.dal.org.po.TXCascadeAccount;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.properties.PropertiesReader;
import com.baijia.tianxiao.validation.ValidateTokenUtil;

import com.google.common.collect.Maps;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;

import lombok.extern.slf4j.Slf4j;

/**
 * @title SyncAccountVersion
 * @desc O(∩_∩)O~
 * @author caoliang
 * @date 2016年10月10日
 * @version 1.0
 */
@Slf4j
@Component
public class SyncAccountVersion {

    private static final int BATCH = 1000;
    private InnerSync innerSync;

    @Autowired
    private OrgSubAccountDao orgSubAccountDao;
    @Autowired
    private TXCascadeAccountDao txCascadeAccountDao;

    @PostConstruct
    public void postConstruct() {
        String runFlag = null;
        try {
            runFlag = StringUtils.defaultIfBlank(PropertiesReader.getValue("config", "innersync.run"), "true");
        } catch (Exception e) {
            runFlag = "true";
        }
        if (StringUtils.equalsIgnoreCase(runFlag.trim(), "false")) {
            return;
        }
        innerSync = new InnerSync();
        innerSync.setDaemon(true);
        innerSync.start();
    }

    @PreDestroy
    public void preDestroy() {
        if (null != innerSync) {
            innerSync.interrupt();
        }
    }

    class InnerSync extends Thread {

        @Override
        public void run() {
            try {
                while (true) {
                    Thread.sleep(60 * 1000);
                    Map<String, Integer> accountVersionMap = Maps.newHashMap();
                    fillOrgSubAccount(accountVersionMap);
                    fillTXCascadeAccount(accountVersionMap);
                    ValidateTokenUtil.accountVersionMap = accountVersionMap;
                }
            } catch (Throwable t) {
                log.warn("InnerSync error!", t);
            }

        }

        private void fillOrgSubAccount(Map<String, Integer> accountVersionMap) {
            log.info("InnerSync start orgSubAccounts ...");
            List<OrgSubAccount> orgSubAccounts = null;
            PageDto pageDto = new PageDto();
            pageDto.setPageSize(BATCH);
            pageDto.setPageNum(1);
            int total = 0;
            do {
                orgSubAccounts = orgSubAccountDao.getAllByPageDto(pageDto);
                if (CollectionUtils.isNotEmpty(orgSubAccounts)) {
                    for (OrgSubAccount orgSubAccount : orgSubAccounts) {
                        accountVersionMap.put(ValidateTokenUtil.ORG_ID_PREFIX + orgSubAccount.getOrgId(),
                            orgSubAccount.getAccountVersion());
                    }
                }
                total += orgSubAccounts.size();
                pageDto.setPageNum(pageDto.getPageNum() + 1);
            } while (orgSubAccounts.size() == BATCH);
            log.info("InnerSync load orgSubAccounts finish! load size:{}", total);
            if (log.isDebugEnabled()) {
                // log.debug("InnerSync load orgSubAccounts finish accountVersionMap :{}", accountVersionMap);
            }
        }

        private void fillTXCascadeAccount(Map<String, Integer> accountVersionMap) {
            List<TXCascadeAccount> txCascadeAccounts = null;
            log.debug("InnerSync start txCascadeAccounts ...");
            PageDto pageDto = new PageDto();
            pageDto.setPageSize(BATCH);
            pageDto.setPageNum(1);
            int total = 0;
            do {
                txCascadeAccounts = txCascadeAccountDao.getAllByPageDto(pageDto);
                if (CollectionUtils.isNotEmpty(txCascadeAccounts)) {
                    for (TXCascadeAccount txCascadeAccount : txCascadeAccounts) {
                        accountVersionMap.put(ValidateTokenUtil.CASCADE_PREFIX + txCascadeAccount.getId(),
                            txCascadeAccount.getAccountVersion());
                    }
                }
                total += txCascadeAccounts.size();
                pageDto.setPageNum(pageDto.getPageNum() + 1);
            } while (txCascadeAccounts.size() == BATCH);
            log.info("InnerSync load txCascadeAccounts finish! load size:{}", total);
        }
    }

}
